from django.conf import settings

DEFAULT_ENV = "WAGTAIL_CODE_BLOCK_LANGUAGES"

def get_language_choices():
    """
    Default list of language choices, if not overridden by Django.
    """
    DEFAULT_LANGUAGES = (
      ('cpp', 'C++'),
      ('java', 'Java'),
      ('python3', 'Python 3'),
      ('bash', 'Bash/Shell'),
      ('javascript', 'Javascript'),
      ('css', "CSS"),
      ('html', "HTML"),
      ('julia', "Julia"),
      ('nginx', "Nginx configuration file"),
      ('numpy', "NumPy"),
      ('django', "Django"),
      ('jinja', "Jinja"),
      ('docker', "Docker"),
      ('jinja', "Jinja"),
      ('yaml', "YAML"),
      ('json', "JSON"),
      ('plpgsql', "PL/pgSQL"),
      ('psql', "PostgreSQL console (psql)"),
    )


    return getattr(settings, DEFAULT_ENV, DEFAULT_LANGUAGES)



from wagtail.core.blocks import (
    CharBlock,
    ChoiceBlock,
    StructBlock,
    StructValue,
    TextBlock
)
from django.utils.safestring import mark_safe
from pygments import highlight
from pygments.formatters import get_formatter_by_name
from pygments.lexers import get_lexer_by_name

from .settings import get_language_choices


class CodeStructValue(StructValue):
    def code(self):
        language = self.get("language")
        src = self.get("src")
        lexer = get_lexer_by_name(language)
        formatter = get_formatter_by_name(
            'html',
            linenos=None,
        )
        render_content = highlight(src, lexer, formatter)
        return mark_safe(render_content)


class CodeBlock(StructBlock):
    language = ChoiceBlock(
        choices=get_language_choices(),
        blank=False,
        null=False,
        default='python'
    )
    caption = CharBlock(required=False, blank=True, nullable=True)
    src = TextBlock()

    class Meta:
        icon = "code"
        value_class = CodeStructValue




import setuptools


with open('README.rst', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='wagtail-pygments',
    version='0.1.1',
    description='A block render syntax highlighter for Wagtail CMS.',
    long_description=long_description,
    url='https://github.com/truongvan/wagtail-pygments.git',
    author='Truong Van',
    author_email='truongvan@live.com',
    license='BSD-3-Clause',
    py_modules=['wagtail_pygments'],
    packages=setuptools.find_packages(),
    install_requires=[
        'pygments>=2.6',
        'wagtail>=2',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Wagtail',
        'Framework :: Wagtail :: 2',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content'
    ]
)
